aboutsummaryrefslogtreecommitdiffstats
path: root/progress_dlg.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2002-08-28 10:07:37 +0000
committerGuy Harris <guy@alum.mit.edu>2002-08-28 10:07:37 +0000
commitabe6b6bcc8e56b3606dec883ead36658a296088e (patch)
tree0d0ee2965686033c7aee032eb363afa81da06afb /progress_dlg.h
parent666f3feec35f96f3cf0a0edbac0299efcf705545 (diff)
From Ulf Lamping: extend the progress dialog box to give more progress
information. Fix the types of some variables (make the file position in "read_cap_file()" a "long", as Wiretap supports "long" offsets, and make processed-packet counts in packet-processing loops "int"s, as the total packet count in a "capture_file" structure is an "int"). svn path=/trunk/; revision=6112
Diffstat (limited to 'progress_dlg.h')
-rw-r--r--progress_dlg.h27
1 files changed, 14 insertions, 13 deletions
diff --git a/progress_dlg.h b/progress_dlg.h
index 2afb7ef31a..974a4ce807 100644
--- a/progress_dlg.h
+++ b/progress_dlg.h
@@ -1,12 +1,11 @@
/* progress_dlg.h
* Definitions for progress dialog box routines
*
- * $Id: progress_dlg.h,v 1.2 2002/07/30 10:13:14 guy Exp $
+ * $Id: progress_dlg.h,v 1.3 2002/08/28 10:07:28 guy Exp $
*
* Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
* Copyright 1998 Gerald Combs
- *
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
@@ -40,30 +39,32 @@ typedef struct progdlg progdlg_t;
* needs in order to manipulate the dialog, and return a pointer to
* it.
*
* The first argument is the title to give the dialog box; the second
* argument is the string to put in the "stop this operation" button;
* the third argument is a pointer to a Boolean variable that will be
* set to TRUE if the user hits that button.
*/
-progdlg_t *create_progress_dlg(const gchar *title, const gchar *stop_title,
- gboolean *stop_flag);
+progdlg_t *create_progress_dlg(const gchar *task_title, const gchar *item_title,
+ const gchar *stop_title, gboolean *stop_flag);
/* Create a progress dialog, but only if it's not likely to disappear
* immediately, which can be disconcerting for the user.
*
- * The first three arguments are as for create_progress_dlg().
+ * The first four arguments are as for create_progress_dlg().
* Following those is a pointer to a GTimeVal structure which holds
* the time at which the caller started to process the data, and the
* current progress (0..1).
*/
-progdlg_t *delayed_create_progress_dlg(const gchar *title,
+progdlg_t *
+delayed_create_progress_dlg(const gchar *task_title, const gchar *item_title,
const gchar *stop_title, gboolean *stop_flag, GTimeVal *start_time,
gfloat progress);
/*
- * Set the percentage value of the progress bar.
+ * Update the progress information of the progress dialog box.
*/
-void update_progress_dlg(progdlg_t *dlg, gfloat percentage);
+void update_progress_dlg(progdlg_t *dlg, gfloat percentage, gchar *status);
/*
* Destroy the progress bar.
@@ -40,30 +39,32 @@ typedef struct progdlg progdlg_t;
* it.
*
- * The first argument is the title to give the dialog box; the second
- * argument is the string to put in the "stop this operation" button;
- * the third argument is a pointer to a Boolean variable that will be
- * set to TRUE if the user hits that button.
+ * The first argument is the task to do, e.g. "Loading".
+ * The second argument is the item to do, e.g. "capture.cap".
+ * The third argument is the string to put in the "stop this operation" button.
+ * The fourth argument is a pointer to a Boolean variable that will be
+ * set to TRUE if the user hits that button.
*/